import store from '../../../store';
import rsCode from '../../../utils/rsCode';


function loadFromServer(type) {
  if (!type) {
    console.error(' load constant with no type');
    return;
  }
  // url : baseURL+"",//路径
  let rs;
  $.ajax({
    type: 'get',
    url: 'http://localhost:8091/vehicle/constant/type/' + type,
    async: false,
    dataType: 'json',
    data: {},
    success: function (result) {
      // 返回数据根据结果进行相应的处理
      if (result.code === rsCode.RS_CODE_SUC) {
        rs = result.data;
      } else {
        console.log('请求常量信息出错。');
      }
    },
    error: function () {
      console.log('请求常量信息出错。');
    }
  });
  return rs;
}

/**
 * 获取对应类型、编码的常量，相关类型未缓存将缓存/5分钟后过期
 * @param type
 * @param code
 * @returns {null|*}
 */
export function getConstantByTypeAndCode(type, code) {
  if (!type) {
    console.error('empty constant type');
    return null;
  }
  if (!code) {
    console.error('empty constant code');
    return null;
  }
  let constantMap = store.getters.vehicleConstants(type);
  if (!constantMap) {
    let constants = loadFromServer(type);
    if (!constants || constants.length === 0) {
      return null;
    }
    constantMap = {};
    for (let index in constants) {
      constantMap[constants[index].code] = constants[index];
    }
    let constantMapAndType = {type, constantMap};
    store.dispatch("cacheConstant", constantMapAndType);
    setTimeout(() => {
      store.dispatch("clearConstant", type);
    }, 5 * 60 * 1000);
  }
  return constantMap[code];
}

export function getConstantListByType(type) {
  if (!type) {
    console.error('empty constant type');
    return null;
  }
  let constantMap = store.getters.vehicleConstants(type);
  if (JSON.stringify(constantMap) === '{}') {
    let constants = loadFromServer(type);
    if (!constants || constants.length === 0) {
      return null;
    }
    constantMap = {};
    for (let index in constants) {
      constantMap[constants[index].code] = constants[index];
    }
    let constantMapAndType = {type, constantMap};
    store.dispatch("cacheConstant", constantMapAndType);
    setTimeout(() => {
      store.dispatch("clearConstant", type);
    }, 5 * 60 * 1000);
  }
  return constantMap;
}
